@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::NumericLevel;
 
-our $DATE = '2019-09-18'; # DATE
-our $VERSION = '0.015'; # VERSION
+our $DATE = '2020-01-13'; # DATE
+our $VERSION = '0.016'; # VERSION
 
 use 5.010001;
 use strict;
@@ -35,7 +35,7 @@ Bencher::Scenario::LogGer::NumericLevel - Benchmark numeric_level()
 
 =head1 VERSION
 
-This document describes version 0.015 of Bencher::Scenario::LogGer::NumericLevel (from Perl distribution Bencher-Scenarios-LogGer), released on 2019-09-18.
+This document describes version 0.016 of Bencher::Scenario::LogGer::NumericLevel (from Perl distribution Bencher-Scenarios-LogGer), released on 2020-01-13.
 
 =head1 SYNOPSIS
 
@@ -85,28 +85,28 @@ Function call template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.26.1 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 18.3 >>, OS kernel: I<< Linux version 4.10.0-38-generic >>.
+Run on: perl: I<< v5.30.0 >>, CPU: I<< Intel(R) Core(TM) i5-7200U CPU @ 2.50GHz (2 cores) >>, OS: I<< GNU/Linux Ubuntu version 19.04 >>, OS kernel: I<< Linux version 5.0.0-37-generic >>.
 
 Benchmark with default options (C<< bencher -m LogGer::NumericLevel >>):
 
  #table1#
- +---------+-----------+-----------+------------+---------+---------+
- | dataset | rate (/s) | time (ns) | vs_slowest |  errors | samples |
- +---------+-----------+-----------+------------+---------+---------+
- | warn    |   2300000 |       440 |        1   | 3.3e-09 |      23 |
- | 10      |   2500000 |       400 |        1.1 | 7.3e-10 |      23 |
- +---------+-----------+-----------+------------+---------+---------+
+ +---------+-----------+-----------+-----------------------+-----------------------+---------+---------+
+ | dataset | rate (/s) | time (ns) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
+ +---------+-----------+-----------+-----------------------+-----------------------+---------+---------+
+ | warn    |   2990000 |     334.5 |                 0.00% |                22.02% | 5.8e-12 |      21 |
+ | 10      |   3650000 |     274   |                22.02% |                 0.00% | 5.2e-11 |      20 |
+ +---------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m LogGer::NumericLevel --module-startup >>):
 
  #table2#
- +---------------------+-----------+------------------------+------------+---------+---------+
- | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +---------------------+-----------+------------------------+------------+---------+---------+
- | Log::ger::Util      |      11   |                    4.6 |        1   | 1.6e-05 |      20 |
- | perl -e1 (baseline) |       6.4 |                    0   |        1.7 |   2e-05 |      20 |
- +---------------------+-----------+------------------------+------------+---------+---------+
+ +---------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
+ | participant         | time (ms) | mod_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
+ +---------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
+ | Log::ger::Util      |     11.4  |              4.52 |                 0.00% |                66.32% | 4.7e-06 |      20 |
+ | perl -e1 (baseline) |      6.88 |              0    |                66.32% |                 0.00% | 3.4e-06 |      20 |
+ +---------------------+-----------+-------------------+-----------------------+-----------------------+---------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
@@ -133,7 +133,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
